==> yt_dlg-1.4.1-py3-none-any.whl: youtube_dl_gui/info.py <==
# -*- coding: utf-8 -*-

"""yt-dlg module that holds package information.

Note:
    All those info could be stored in the __init__ file
    but we keep them here to keep the code clean.

"""


__author__ = "Sotiris Papadopoulos"
__contact__ = "ytubedlg@gmail.com"
__maintainer__ = "Oleksis Fraga"
__maintainer_contact__ = "oleksis.fraga@gmail.com"
__projecturl__ = "https://github.com/oleksis/youtube-dl-gui/"

__appname__ = "yt-dlg"
__packagename__ = "youtube_dl_gui"
__license__ = "UNLICENSE"

__description__ = "Youtube Downloader GUI"

__descriptionfull__ = """A cross platform front-end GUI of the popular
youtube-dl written in wxPython Phoenix"""

__licensefull__ = """
This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or
distribute this software, either in source code form or as a compiled
binary, for any purpose, commercial or non-commercial, and by any
means.

In jurisdictions that recognize copyright laws, the author or authors
of this software dedicate any and all copyright interest in the
software to the public domain. We make this dedication for the benefit
of the public at large and to the detriment of our heirs and
successors. We intend this dedication to be an overt act of
relinquishment in perpetuity of all present and future rights to this
software under copyright law.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

For more information, please refer to <http://unlicense.org/>"""

==> yt_dlg-1.8.1-py3-none-any.whl: youtube_dl_gui/info.py <==
"""yt-dlg module that holds package information.

Note:
    All those info could be stored in the __init__ file
    but we keep them here to keep the code clean.

"""


__author__ = "Sotiris Papadopoulos"
__contact__ = "ytubedlg@gmail.com"
__maintainer__ = "Oleksis Fraga"
__maintainer_contact__ = "oleksis.fraga@gmail.com"
__projecturl__ = "https://oleksis.github.io/youtube-dl-gui/"
__githuburl__ = "https://github.com/oleksis/youtube-dl-gui/"

__appname__ = "yt-dlg"
__packagename__ = "youtube_dl_gui"
__license__ = "UNLICENSE"

__description__ = "Youtube Downloader GUI"

__descriptionfull__ = """A cross platform front-end GUI of the popular
youtube-dl written in wxPython Phoenix"""

__licensefull__ = """
This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or
distribute this software, either in source code form or as a compiled
binary, for any purpose, commercial or non-commercial, and by any
means.

In jurisdictions that recognize copyright laws, the author or authors
of this software dedicate any and all copyright interest in the
software to the public domain. We make this dedication for the benefit
of the public at large and to the detriment of our heirs and
successors. We intend this dedication to be an overt act of
relinquishment in perpetuity of all present and future rights to this
software under copyright law.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

For more information, please refer to <http://unlicense.org/>"""
